@@ -5,8 +5,8 @@ by converting graphics into colorized ascii-art. asciiporn has 256 color support
 & is partially written in c for efficent graphics rendering.
 asciiporn can easily render 24bit megapixel graphics on a 1ghz 500mb machine
 
-screenshots of both plotting and image viewing r included w/ this distribution.
-asciiporn is hard-coded to use lucida-console font, but courier font will work
+screenshots of both image viewing & plotting r included w/ this distribution.
+asciiporn is hard-coded with lucida-console font, but courier font will work
 as well. the screenshots show putty ssh w/ lucida-console 5pt.
 
 how to enable 256 color in putty:  http://www.emacswiki.org/emacs/PuTTY#toc2
@@ -29,8 +29,8 @@ for quick example usage, remotely run python in an ssh terminal:
   >>> from math import sin, pi
   >>> print plot3d(
   ...   ftz = lambda t, z: sin(t + t*z), ## 3d function
-  ...   tmin = 0.0, tmax = 2*pi,         ## range of t
-  ...   zmin = 0.0, zmax = 0.25,         ## range of z
+  ...   tmin = 0.0, tmax = 2*pi,         ## t parameter
+  ...   zmin = 0.0, zmax = 0.25,         ## z parameter
   ... )
 
 AUTHOR:
@@ -351,7 +351,7 @@ __platforms__ = None
 __provides__ = None
 __requires__ = ["PIL", "numpy"]
 __url__ = "http://pypi.python.org/pypi/asciiporn"
-__version__ = "2009.01.25"
+__version__ = "2009.02.01"
 ## end setup info
 
 
